changeset 10557:23e8673c32c3

<moonythedwarf> ` cd nasmbuild/nasm-2.13rc9; ./configure > confoutput
author HackBot
date Thu, 30 Mar 2017 21:05:13 +0000
parents 3b3668d71811
children 93cc9ee346ac
files nasmbuild/nasm-2.13rc9/confdefs.h nasmbuild/nasm-2.13rc9/config.log nasmbuild/nasm-2.13rc9/confoutput nasmbuild/nasm-2.13rc9/conftest.c
diffstat 4 files changed, 98 insertions(+), 15 deletions(-) [+]
line wrap: on
line diff
--- a/nasmbuild/nasm-2.13rc9/confdefs.h	Thu Mar 30 21:03:42 2017 +0000
+++ b/nasmbuild/nasm-2.13rc9/confdefs.h	Thu Mar 30 21:05:13 2017 +0000
@@ -41,4 +41,3 @@
 #define HAVE_GETUID 1
 #define HAVE_GETGID 1
 #define HAVE_REALPATH 1
-#define HAVE_CANONICALIZE_FILE_NAME 1
--- a/nasmbuild/nasm-2.13rc9/config.log	Thu Mar 30 21:03:42 2017 +0000
+++ b/nasmbuild/nasm-2.13rc9/config.log	Thu Mar 30 21:05:13 2017 +0000
@@ -989,7 +989,7 @@
 configure:6139: result: yes
 configure:6139: checking for stricmp
 configure:6139: gcc -std=gnu99 -o conftest -g -O3 -fwrapv -U__STRICT_ANSI__ -fno-common   conftest.c  >&5
-/tmp/cc4pIDn0.o: In function `main':
+/tmp/ccMhA8JI.o: In function `main':
 /hackenv/nasmbuild/nasm-2.13rc9/conftest.c:73: undefined reference to `stricmp'
 collect2: error: ld returned 1 exit status
 configure:6139: $? = 1
@@ -1080,7 +1080,7 @@
 configure:6151: result: yes
 configure:6151: checking for strnicmp
 configure:6151: gcc -std=gnu99 -o conftest -g -O3 -fwrapv -U__STRICT_ANSI__ -fno-common   conftest.c  >&5
-/tmp/cc4XWJLk.o: In function `main':
+/tmp/ccbQZw6g.o: In function `main':
 /hackenv/nasmbuild/nasm-2.13rc9/conftest.c:74: undefined reference to `strnicmp'
 collect2: error: ld returned 1 exit status
 configure:6151: $? = 1
@@ -1185,7 +1185,3 @@
 configure:6208: result: yes
 configure:6219: checking for canonicalize_file_name
 configure:6219: gcc -std=gnu99 -o conftest -g -O3 -fwrapv -U__STRICT_ANSI__ -fno-common   conftest.c  >&5
-configure:6219: $? = 0
-configure:6219: result: yes
-configure:6230: checking for _fullpath
-configure:6230: gcc -std=gnu99 -o conftest -g -O3 -fwrapv -U__STRICT_ANSI__ -fno-common   conftest.c  >&5
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/nasmbuild/nasm-2.13rc9/confoutput	Thu Mar 30 21:05:13 2017 +0000
@@ -0,0 +1,89 @@
+checking for prefix by checking for nasm... no
+checking for gcc... gcc
+checking whether the C compiler works... yes
+checking for C compiler default output file name... a.out
+checking for suffix of executables... 
+checking whether we are cross compiling... no
+checking for suffix of object files... o
+checking whether we are using the GNU C compiler... yes
+checking whether gcc accepts -g... yes
+checking for gcc option to accept ISO C89... none needed
+checking how to run the C preprocessor... gcc -E
+checking for grep that handles long lines and -e... /bin/grep
+checking for egrep... /bin/grep -E
+checking for ANSI C header files... yes
+checking for sys/types.h... yes
+checking for sys/stat.h... yes
+checking for stdlib.h... yes
+checking for string.h... yes
+checking for memory.h... yes
+checking for strings.h... yes
+checking for inttypes.h... yes
+checking for stdint.h... yes
+checking for unistd.h... yes
+checking minix/config.h usability... no
+checking minix/config.h presence... no
+checking for minix/config.h... no
+checking whether it is safe to define __EXTENSIONS__... yes
+checking for special C compiler options needed for large files... no
+checking for _FILE_OFFSET_BITS value needed for large files... no
+checking for gcc... (cached) gcc
+checking whether we are using the GNU C compiler... (cached) yes
+checking whether gcc accepts -g... (cached) yes
+checking for gcc option to accept ISO C89... (cached) none needed
+checking for gcc option to accept ISO C99... -std=gnu99
+checking for gcc -std=gnu99 option to accept ISO Standard C... (cached) -std=gnu99
+checking whether ln -s works... yes
+checking whether make sets $(MAKE)... yes
+checking for a BSD-compatible install... /usr/bin/install -c
+checking for suffix of library files... a
+checking for an ANSI C-conforming const... yes
+checking for inline... inline
+checking for C/C++ restrict keyword... __restrict
+checking for size_t... yes
+checking whether byte ordering is bigendian... no
+checking if gcc -std=gnu99 accepts -fwrapv... yes
+checking if gcc -std=gnu99 accepts -U__STRICT_ANSI__... yes
+checking if gcc -std=gnu99 accepts -fno-common... yes
+checking for nroff... nroff
+checking for asciidoc... no
+checking for xmlto... no
+checking for acrodist... no
+checking for ps2pdf... no
+checking for pstopdf... no
+checking for ar... ar
+checking for ranlib... ranlib
+checking for strip... strip
+checking for ANSI C header files... (cached) yes
+checking for inttypes.h... (cached) yes
+checking for strings.h... (cached) yes
+checking for stdbool.h that conforms to C99... yes
+checking for _Bool... yes
+checking stdnoreturn.h usability... yes
+checking stdnoreturn.h presence... yes
+checking for stdnoreturn.h... yes
+checking io.h usability... no
+checking io.h presence... no
+checking for io.h... no
+checking fcntl.h usability... yes
+checking fcntl.h presence... yes
+checking for fcntl.h... yes
+checking for unistd.h... (cached) yes
+checking sys/param.h usability... yes
+checking sys/param.h presence... yes
+checking for sys/param.h... yes
+checking sys/mman.h usability... yes
+checking sys/mman.h presence... yes
+checking for sys/mman.h... yes
+checking for sys/stat.h... (cached) yes
+checking for sys/types.h... (cached) yes
+checking for strcasecmp... yes
+checking for stricmp... no
+checking for strncasecmp... yes
+checking for strnicmp... no
+checking for strsep... yes
+checking for strnlen... yes
+checking for getuid... yes
+checking for getgid... yes
+checking for realpath... yes
+checking for canonicalize_file_name... 
\ No newline at end of file
--- a/nasmbuild/nasm-2.13rc9/conftest.c	Thu Mar 30 21:03:42 2017 +0000
+++ b/nasmbuild/nasm-2.13rc9/conftest.c	Thu Mar 30 21:05:13 2017 +0000
@@ -41,14 +41,13 @@
 #define HAVE_GETUID 1
 #define HAVE_GETGID 1
 #define HAVE_REALPATH 1
-#define HAVE_CANONICALIZE_FILE_NAME 1
 /* end confdefs.h.  */
 /* Define _fullpath to an innocuous variant, in case <limits.h> declares _fullpath.
    For example, HP-UX 11i <limits.h> declares gettimeofday.  */
-#define _fullpath innocuous__fullpath
+#define canonicalize_file_name innocuous_canonicalize_file_name
 
 /* System header to define __stub macros and hopefully few prototypes,
-    which can conflict with char _fullpath (); below.
+    which can conflict with char canonicalize_file_name (); below.
     Prefer <limits.h> to <assert.h> if __STDC__ is defined, since
     <limits.h> exists even on freestanding compilers.  */
 
@@ -58,7 +57,7 @@
 # include <assert.h>
 #endif
 
-#undef _fullpath
+#undef canonicalize_file_name
 
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
@@ -66,18 +65,18 @@
 #ifdef __cplusplus
 extern "C"
 #endif
-char _fullpath ();
+char canonicalize_file_name ();
 /* The GNU C library defines this for functions which it implements
     to always fail with ENOSYS.  Some functions are actually named
     something starting with __ and the normal name is an alias.  */
-#if defined __stub__fullpath || defined __stub____fullpath
+#if defined __stub_canonicalize_file_name || defined __stub___canonicalize_file_name
 choke me
 #endif
 
 int
 main ()
 {
-return _fullpath ();
+return canonicalize_file_name ();
   ;
   return 0;
 }
@@ -41,14 +41,13 @@
 /* end confdefs.h.  */
-/* Define _fullpath to an innocuous variant, in case <limits.h> declares _fullpath.
+/* Define canonicalize_file_name to an innocuous variant, in case <limits.h> declares canonicalize_file_name.
    For example, HP-UX 11i <limits.h> declares gettimeofday.  */